
#ifndef _C14_ds660_
#define _C14_ds660_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F1214_8549(EIF_REFERENCE, EIF_REFERENCE);
extern void F1214_8553(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit660(void);

#ifdef __cplusplus
}
#endif

#endif
